@@ -8,7 +8,8 @@ import Text.HTML.TagSoup.Match
 
 import Control.Monad
 import Data.List
-import Test.QuickCheck
+import Test.QuickCheck(Arbitrary(..), Testable(..), quickCheckWithResult, stdArgs,
+                       Args(..), listOf, elements, Result(..))
 
 -- * The Test Monad
 
@@ -115,6 +116,7 @@ parseTests = do
     parseTags "hello &amp; world" === [TagText "hello & world"]
     parseTags "hello &#64; world" === [TagText "hello @ world"]
     parseTags "hello &#x40; world" === [TagText "hello @ world"]
+    parseTags "hello &#X40; world" === [TagText "hello @ world"]
     parseTags "hello &haskell; world" === [TagText "hello &haskell; world"]
     parseTags "hello \n\t world" === [TagText "hello \n\t world"]
     parseTags "<a href=http://www.google.com>" === [TagOpen "a" [("href","http://www.google.com")]]
@@ -150,6 +152,16 @@ parseTests = do
     parseTags "<p>some text</p\n<img alt='&lt; &yyy; &gt;' src=\"abc.gif\">" ===
         [TagOpen "p" [],TagText "some text",TagClose "p"]
 
+    parseTags "<script> if (x<bomb) </script>" === [TagOpen "script" [], TagText " if (x<bomb) ", TagClose "script"]
+    parseTags "<script> if (x<bomb) " === [TagOpen "script" [], TagText " if (x<bomb) "]
+    parseTags "<SCRIPT language=foo> if (x<bomb) </SCRIPT>" === [TagOpen "SCRIPT" [("language","foo")], TagText " if (x<bomb) ", TagClose "SCRIPT"]
+    parseTags "<script /><test>" === [TagOpen "script" [], TagClose "script", TagOpen "test" []]
+
+    -- some escapes require trailing semicolons, see #28 and #27.
+    parseTags "one &mid; two" === [TagText "one \8739 two"]
+    parseTags "one &mid two" === [TagText "one &mid two"]
+    parseTags "one &micro; two" === [TagText "one \181 two"]
+    parseTags "one &micro two" === [TagText "one \181 two"]
 
 optionsTests :: Test ()
 optionsTests = check $ \(HTML x) -> all (f x) $ replicateM 3 [False,True]
@@ -203,6 +215,7 @@ entityTests = do
     lookupNumericEntity "x41" === Just "A"
     lookupNumericEntity "x4E" === Just "N"
     lookupNumericEntity "x4e" === Just "N"
+    lookupNumericEntity "X4e" === Just "N"
     lookupNumericEntity "Haskell" === Nothing
     lookupNumericEntity "" === Nothing
     lookupNumericEntity "89439085908539082" === Nothing
